ResponseContent

Trait ResponseContent 

pub trait ResponseContent {
    // Required method
    fn content(&self) -> String;
}
A trait for extracting the content from a language model’s response.

Required Methods

fn content(&self) -> String

Retrieves the main content from the response.

Returns

A string containing the text content of the response.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors