Reference: https://dagrs.com/docs/getting-started/components
Macros
- dependencies
- The
dependencies!macro allows users to specify all task dependencies in an easy-to-understand way. It will return the generated graph structure based on a set of defined dependencies
Structs
- Content
- Container type to store task output.
- Default
Node - Default node type
- Empty
Action - An empty implementaion of
Action. - EnvVar
- Environment variable.
- Graph
Graphis dagrs’s main body.- InChannels
- Input Channels
- NodeId
- Node
Table - NodeTable: a mapping from Node’s name to NodeId.
- OutChannels
- Output Channels
Enums
- Output
Outputrepresents the output of a node. Different from information packet (Content, used to communicate with other Nodes),Outputcarries the information thatNodeneeds to pass to theGraph.- RecvErr
- Input Channel Error Types
- SendErr
- Output Channel Error Types
Traits
Type Aliases
Attribute Macros
- auto_
node - [
auto_node] is a macro that may be used when customizing nodes. It can only be marked on named struct or unit struct.