dependencies!() { /* proc-macro */ }Expand description
The dependencies! macro allows users to specify all task dependencies in an easy-to-understand
way. It will return the generated graph structure based on a set of defined dependencies
dependencies!() { /* proc-macro */ }The dependencies! macro allows users to specify all task dependencies in an easy-to-understand
way. It will return the generated graph structure based on a set of defined dependencies