DefaultNode

Struct DefaultNode 

pub struct DefaultNode { /* private fields */ }
Default node type

DefaultNode is a default implementation of the Node trait. Users can use this node type to build tasks to meet most needs.

Create a DefaultNode:

  • use the method new. Required attributes: node’s name; NodeTable(for id allocation).
use dagrs::{NodeName, NodeTable, DefaultNode};

let node_name = "Node X";
let mut node_table = NodeTable::new();
let mut node = DefaultNode::new(
    NodeName::from(node_name),
    &mut node_table,
);
  • use the method with_action. Required attributes: node’s name; NodeTable(for id allocation); execution logic Action.
use dagrs::{NodeName, NodeTable, DefaultNode, EmptyAction};

let node_name = "Node X";
let mut node_table = NodeTable::new();
let mut node = DefaultNode::with_action(
    NodeName::from(node_name),
    EmptyAction,
    &mut node_table,
);

Implementations

Source

impl DefaultNode

pub fn new(name: String, node_table: &mut NodeTable) -> DefaultNode

pub fn with_action( name: String, action: impl Action + 'static, node_table: &mut NodeTable, ) -> DefaultNode

pub fn set_action(&mut self, action: impl Action + 'static)