pub struct EnvVar { /* private fields */ }Expand description
Environment variable.
When multiple nodes are running, they may need to share the same data or read
the same configuration information. Environment variables can meet this requirement.
Before all nodes run, the user builds a EnvVar and sets all the environment
variables. One EnvVar corresponds to one dag. All nodes in a job can
be shared and immutable at runtime. environment variables.
Variables that EnvVar should have:
Implementations
Sourceimpl EnvVar
impl EnvVar
Sourcepub fn set<H>(&mut self, name: &str, var: H)
pub fn set<H>(&mut self, name: &str, var: H)
Set a global variables.
Example
use dagrs::{EnvVar, NodeTable};
env.set("Hello", "World".to_string());Trait Implementations