InChannels

Struct InChannels 

pub struct InChannels(/* private fields */);
Input Channels

A hash-table mapping NodeId to InChannel. In Dagrs, each Node stores input channels in this map, enabling Node to receive information packets from other Nodes.

Implementations

Source

impl InChannels

pub fn blocking_recv_from(&mut self, id: &NodeId) -> Result<Content, RecvErr>

Perform a blocking receive on the incoming channel from NodeId.

pub async fn recv_from(&mut self, id: &NodeId) -> Result<Content, RecvErr>

Perform a asynchronous receive on the incoming channel from NodeId.

pub fn blocking_map<F, T>(&mut self, f: F) -> Vec<T>
where F: FnMut(Result<Content, RecvErr>) -> T,

Calls blocking_recv for all the InChannels, and applies transformation f to the return values of the call.

pub async fn map<F, T>(&mut self, f: F) -> Vec<T>
where F: FnMut(Result<Content, RecvErr>) -> T,

Calls recv for all the InChannels, and applies transformation f to the return values of the call asynchronously.

pub async fn close_async(&mut self, id: &NodeId)

Close the channel by the given NodeId asynchronously, and remove the channel in this map.

pub fn close(&mut self, id: &NodeId)

Close the channel by the given NodeId, and remove the channel in this map.