pub struct OutChannels(/* private fields */);Expand description
Output Channels
A hash-table mapping NodeId to OutChannel. In Dagrs, each Node stores output
channels in this map, enabling Node to send information packets to other Nodes.
Implementations
Sourceimpl OutChannels
impl OutChannels
Sourcepub fn blocking_send_to(
&self,
id: &NodeId,
content: Content,
) -> Result<(), SendErr>
pub fn blocking_send_to( &self, id: &NodeId, content: Content, ) -> Result<(), SendErr>
Perform a blocking send on the outcoming channel from NodeId.
Sourcepub async fn send_to(
&self,
id: &NodeId,
content: Content,
) -> Result<(), SendErr>
pub async fn send_to( &self, id: &NodeId, content: Content, ) -> Result<(), SendErr>
Perform a asynchronous send on the outcoming channel from NodeId.
Sourcepub async fn broadcast(&self, content: Content) -> Vec<Result<(), SendErr>>
pub async fn broadcast(&self, content: Content) -> Vec<Result<(), SendErr>>
Broadcasts the content to all the OutChannels asynchronously.
Sourcepub fn blocking_broadcast(&self, content: Content) -> Vec<Result<(), SendErr>>
pub fn blocking_broadcast(&self, content: Content) -> Vec<Result<(), SendErr>>
Blocking broadcasts the content to all the OutChannels.