Module memory

Module memory 

Structs

Message
Represents a message with content, type, optional ID, and optional tool calls.
RLUCacheMemory
A memory structure that stores messages in an LRU (Least Recently Used) cache.
WindowBufferMemory
A memory structure that stores messages in a sliding window buffer.

Enums

MessageType
Represents the type of a message.

Traits

Memory
A trait representing a memory storage for messages.