Module flow

Module flow 

Reference: https://dagrs.com/docs/getting-started/components

Macros

dependencies
The dependencies! macro allows users to specify all task dependencies in an easy-to-understand way. It will return the generated graph structure based on a set of defined dependencies

Structs

Content
Container type to store task output.
DefaultNode
Default node type
EmptyAction
An empty implementaion of Action.
EnvVar
Environment variable.
Graph
Graph is dagrs’s main body.
InChannels
Input Channels
NodeId
NodeTable
NodeTable: a mapping from Node’s name to NodeId.
OutChannels
Output Channels

Enums

Output
Output represents the output of a node. Different from information packet (Content, used to communicate with other Nodes), Output carries the information that Node needs to pass to the Graph.
RecvErr
Input Channel Error Types
SendErr
Output Channel Error Types

Traits

Action
Node specific behavior
Node
The Node trait

Type Aliases

NodeName

Attribute Macros

auto_node
[auto_node] is a macro that may be used when customizing nodes. It can only be marked on named struct or unit struct.