pub struct InChannels(/* private fields */);Expand description
Input Channels
A hash-table mapping NodeId to InChannel. In Dagrs, each Node stores input
channels in this map, enabling Node to receive information packets from other Nodes.
Implementations
Sourceimpl InChannels
impl InChannels
Sourcepub fn blocking_recv_from(&mut self, id: &NodeId) -> Result<Content, RecvErr>
pub fn blocking_recv_from(&mut self, id: &NodeId) -> Result<Content, RecvErr>
Perform a blocking receive on the incoming channel from NodeId.
Sourcepub async fn recv_from(&mut self, id: &NodeId) -> Result<Content, RecvErr>
pub async fn recv_from(&mut self, id: &NodeId) -> Result<Content, RecvErr>
Perform a asynchronous receive on the incoming channel from NodeId.
Sourcepub fn blocking_map<F, T>(&mut self, f: F) -> Vec<T>
pub fn blocking_map<F, T>(&mut self, f: F) -> Vec<T>
Calls blocking_recv for all the InChannels, and applies transformation f to
the return values of the call.
Sourcepub async fn map<F, T>(&mut self, f: F) -> Vec<T>
pub async fn map<F, T>(&mut self, f: F) -> Vec<T>
Calls recv for all the InChannels, and applies transformation f to
the return values of the call asynchronously.
Sourcepub async fn close_async(&mut self, id: &NodeId)
pub async fn close_async(&mut self, id: &NodeId)
Close the channel by the given NodeId asynchronously, and remove the channel in this map.