Structs
- Message
- Represents a message with content, type, optional ID, and optional tool calls.
- RLUCache
Memory - A memory structure that stores messages in an LRU (Least Recently Used) cache.
- Window
Buffer Memory - A memory structure that stores messages in a sliding window buffer.
Enums
- Message
Type - Represents the type of a message.
Traits
- Memory
- A trait representing a memory storage for messages.